# Ming/Ruby
# $Id: extconf.rb,v 1.4 2002/06/24 14:12:12 daisu-ik Exp $

require "mkmf"

dir_config('ming')

if have_library("ming", "newSWFShape") and
	have_header("ming.h") 
  if have_library("ming", "SWFMovie_setButtonSound")
	$defs.push '-DSUPPORT_PCM'
  end
  if have_library("ming", "SWFBrowserFont_setFlags")
	$defs.push '-DSUPPORT_JAPANESE_BROWSER_FONTS'
  end
  create_makefile("ming")
end

