s/setScale/set_scale/g;

s/nextFrame/next_frame/g;
s/setBackground/set_background/g;
s/setRate/set_rate/g;
s/setDimension/set_dimension/g;
s/setFrames/set_frames/g;

s/setLine/set_line/g;
s/addFill/add_fill/g;
s/setLeftFill/set_left_fill/g;
s/setRightFill/set_right_fill/g;
s/movePenTo/move_pen_to/g;
s/movePen/move_pen/g;
s/drawLineTo/draw_line_to/g;
s/drawLine/draw_line/g;
s/drawCurveTo/draw_curve_to/g;
s/drawCurve/draw_curve/g;
s/drawGlyph/draw_glyph/g;

s/setName/set_name/g;
s/setRatio/set_ratio/g;
s/addColor/add_color/g;
s/multColor/mult_color/g;

s/addEntry/add_entry/g;

s/getWidth/get_width/g;
s/getHeight/get_height/g;

s/moveTo/move_to/g;
s/scaleTo/scale_to/g;
s/rotateTo/rotate_to/g;
s/skewXTo/skew_x_to/g;
s/skewYTo/skew_y_to/g;

s/getShape1/get_shape1/g;
s/getShape2/get_shape2/g;

s/setFont/set_font/g;
s/setHeight/set_height/g;
s/setSpacing/set_spacing/g;
s/setColor/set_color/g;
s/addString/add_string/g;
s/getAscent/get_ascent/g;

s/setBounds/set_bounds/g;
s/setLeftMargin/set_left_margin/g;
s/setRightMargin/set_right_margin/g;
s/setMargins/set_margins/g;
s/setIndentation/set_indentation/g;
s/setLineSpacing/set_line_spacing/g;

s/addShape/add_shape/g;
s/setUp/set_up/g;
s/setDown/set_down/g;
s/setOver/set_over/g;
s/setHit/set_hit/g;
s/addAction/add_action/g;
s/setAction/set_action/g;

s/setDepth/set_depth/g;
